summaryrefslogtreecommitdiffhomepage
path: root/src/utils.c
diff options
context:
space:
mode:
authorRay <[email protected]>2021-05-30 18:02:06 +0200
committerRay <[email protected]>2021-05-30 18:02:06 +0200
commit71995d52b36c86b09f064953fb3dd2d2fd60c704 (patch)
tree152651cd09fdecab36f3928222783d99fd1865d7 /src/utils.c
parenta178a2170bb821fbee135c17fc166733caa19bda (diff)
downloadraylib-71995d52b36c86b09f064953fb3dd2d2fd60c704.tar.gz
raylib-71995d52b36c86b09f064953fb3dd2d2fd60c704.zip
REVIEWED: exit() on LOG_FATAL instead of LOG_ERROR #1796
Diffstat (limited to 'src/utils.c')
-rw-r--r--src/utils.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/utils.c b/src/utils.c
index c21d2318..2df0a939 100644
--- a/src/utils.c
+++ b/src/utils.c
@@ -155,7 +155,7 @@ void TraceLog(int logType, const char *text, ...)
va_end(args);
- if (logType == LOG_ERROR) exit(1); // If error, exit program
+ if (logType == LOG_FATAL) exit(EXIT_FAILURE); // If fatal logging, exit program
#endif // SUPPORT_TRACELOG
}